# Filtering

`flarchitect` supports expressive, URL‑based filtering out of the box. This page
explains how to enable/disable filtering, the syntax for predicates, how to
combine conditions with AND/OR, and how to filter across joined models.

## Sections

- [Enable or disable filtering](enable-or-disable-filtering.md)
- [Basic syntax](basic-syntax.md)
- [Supported operators](supported-operators.md)
- [OR conditions](or-conditions.md)
- [Filtering across joins](filtering-across-joins.md)
- [Tips and combinations](tips-and-combinations.md)
- [Examples](examples.md)
